@@ -18,13 +18,13 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include <QtCore/QStringList>
+#include <QStringList>
 #include "servicetypebrowser.h"
 
 namespace KDNSSD
 {
 
-ServiceTypeBrowser::ServiceTypeBrowser(const QString &, QObject *parent) : QObject(parent), d(0)
+ServiceTypeBrowser::ServiceTypeBrowser(const QString &, QObject *parent) : QObject(parent), d(nullptr)
 {}
 
 ServiceTypeBrowser::~ServiceTypeBrowser()
